#!/usr/bin/python3
# -*- coding: utf-8 -*-

from setuptools import setup



setup(
    name="kot_run",
    version="0.0.0",
    description="""KOT""",
    url="https://github.com/KOT",
    author='Onur Atakan ULUSOY',
    author_email='atadogan06@gmail.com',
    license='MIT',
    python_requires=">= 3",
    zip_safe=False,
)


